@@ -216,8 +216,8 @@ class Repository(object):
 		self.execute('git submodule foreach git fetch')
 
 
-	def reset(self):
-		self.execute('git reset --hard')
+	def reset(self, remote: str = ""):
+		self.execute(f'git reset --hard {remote}')
 
 
 	def clean(self, removeUntrackedFiles: bool = True, removeUntrackedDirectory: bool = True, removeIgnored: bool = False):
@@ -242,6 +242,15 @@ class Repository(object):
 		shutil.rmtree(self.path, onerror=self.fixPermissions)
 
 
+	def setUpstream(self, remote: str = None, branch: str = None, repository: str = None):
+		if not repository:
+			if not remote or not branch:
+				raise Exception("Missing information. Remote and branch, or repository required.")
+			repository = f'{remote}/{branch}'
+		out, err = self.execute(f'git branch --set-upstream-to {repository}')
+		return out, err
+
+
 	@staticmethod
 	def fixPermissions(func: Callable, path: Path, *_args):
 		if not os.access(path, os.W_OK):
@@ -417,7 +426,7 @@ class Remote(object):
 		:param ahead: True: get the number the remote is ahead of HEAD; False: get the commits, remote is behind of HEAD
 		:return:
 		"""
-		subprocess.run(f'git -C {str(self.repository.path)} fetch', shell=True)
+		subprocess.run(f'git -C {str(self.repository.path)} fetch {self.name}', shell=True)
 		ref = f'{self.name}/{branch}..HEAD' if ahead else f'HEAD..{self.name}/{branch}'
 		proc = subprocess.run(f'git -C {str(self.repository.path)} rev-list --count {ref}', shell=True, capture_output=True, text=True)
 		if not proc.stdout:
